==> haskell-network-protocol-xmpp-0.4.10-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-protocol-xmpp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network-protocol-xmpp
version:              0.4.10
visibility:           public
id:                   network-protocol-xmpp-0.4.10-Dxiu6aWGZVCEwHIOfF8fzA
key:                  network-protocol-xmpp-0.4.10-Dxiu6aWGZVCEwHIOfF8fzA
license:              GPL-3.0-only
maintainer:           Stephen Paul Weber <singpolyma@singpolyma.net>
author:
    John Millikin <jmillikin@gmail.com>, Stephan Maka <stephan@spaceboyz.net>

stability:            experimental
homepage:             https://git.sr.ht/~singpolyma/network-protocol-xmpp
synopsis:             Client library for the XMPP protocol.
category:             Network
abi:                  62946ce18cc4e7cdc986df062d2601af
exposed:              True
exposed-modules:      Network.Protocol.XMPP Network.Protocol.XMPP.Internal
hidden-modules:
    Network.Protocol.XMPP.Client
    Network.Protocol.XMPP.Client.Authentication
    Network.Protocol.XMPP.Client.Features
    Network.Protocol.XMPP.Component Network.Protocol.XMPP.Connections
    Network.Protocol.XMPP.ErrorT Network.Protocol.XMPP.Handle
    Network.Protocol.XMPP.JID Network.Protocol.XMPP.Monad
    Network.Protocol.XMPP.Stanza Network.Protocol.XMPP.XML
    Network.Protocol.XMPP.String

import-dirs:          /usr/lib/ghc-9.0.1/site-local/network-protocol-xmpp-0.4.10
library-dirs:         /usr/lib/ghc-9.0.1/site-local/network-protocol-xmpp-0.4.10
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/network-protocol-xmpp-0.4.10

hs-libraries:         HSnetwork-protocol-xmpp-0.4.10-Dxiu6aWGZVCEwHIOfF8fzA
depends:
    base-4.15.0.0 bytestring-0.10.12.1
    gnuidn-0.2.2-C6DbkTZht2JJu5edkNXtlF
    gnutls-0.2-1rYqm6o5j2S9Bq3BL2WaSv
    gsasl-0.3.7-4CodbIw66CV2FUzyvqso1M
    libxml-sax-0.7.5-BLDIL76EkuEJpC01BeoKHC
    monads-tf-0.1.0.3-FhjV1qTiZJq2D5pKEDYJP3
    network-3.1.2.5-G1eUSsEvU7HJvhh4H9urei
    network-simple-0.4.5-I3peHuCK9zthPNK7GnUzL text-1.2.4.1
    transformers-0.5.6.2 xml-types-0.3.8-144bFK4Wa4uGyLKj6w2QbB

haddock-interfaces:
    /usr/share/doc/haskell-network-protocol-xmpp/html/network-protocol-xmpp.haddock

haddock-html:         /usr/share/doc/haskell-network-protocol-xmpp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-protocol-xmpp-0.4.10-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-protocol-xmpp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network-protocol-xmpp
version:              0.4.10
visibility:           public
id:                   network-protocol-xmpp-0.4.10-Hp3bpH8T5IuWS3Sg7V8iS
key:                  network-protocol-xmpp-0.4.10-Hp3bpH8T5IuWS3Sg7V8iS
license:              GPL-3.0-only
maintainer:           Stephen Paul Weber <singpolyma@singpolyma.net>
author:
    John Millikin <jmillikin@gmail.com>, Stephan Maka <stephan@spaceboyz.net>

stability:            experimental
homepage:             https://git.sr.ht/~singpolyma/network-protocol-xmpp
synopsis:             Client library for the XMPP protocol.
category:             Network
abi:                  109b5c4605137b47efacf6c1aa5620ac
exposed:              True
exposed-modules:      Network.Protocol.XMPP Network.Protocol.XMPP.Internal
hidden-modules:
    Network.Protocol.XMPP.Client
    Network.Protocol.XMPP.Client.Authentication
    Network.Protocol.XMPP.Client.Features
    Network.Protocol.XMPP.Component Network.Protocol.XMPP.Connections
    Network.Protocol.XMPP.ErrorT Network.Protocol.XMPP.Handle
    Network.Protocol.XMPP.JID Network.Protocol.XMPP.Monad
    Network.Protocol.XMPP.Stanza Network.Protocol.XMPP.XML
    Network.Protocol.XMPP.String

import-dirs:          /usr/lib/ghc-9.0.2/site-local/network-protocol-xmpp-0.4.10
library-dirs:         /usr/lib/ghc-9.0.2/site-local/network-protocol-xmpp-0.4.10
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.2/network-protocol-xmpp-0.4.10

hs-libraries:         HSnetwork-protocol-xmpp-0.4.10-Hp3bpH8T5IuWS3Sg7V8iS
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    gnuidn-0.2.2-9ET5SrAMmESI4V14cyTjHe
    gnutls-0.2-BqAtU0crXMtD7K2qKBMR6f
    gsasl-0.3.7-FYY5np9HZnOF5YRxWLAq6n
    libxml-sax-0.7.5-LHQZjHtnpgS3xRGlDiwwnx
    monads-tf-0.1.0.3-LS0v3a5UuzO9oiSqbetO8t
    network-3.1.2.7-EdwWg1HzTu96DUWsrJpQQz
    network-simple-0.4.5-D0TMXJPsqkHoPueZLP7B7 text-1.2.5.0
    transformers-0.5.6.2 xml-types-0.3.8-5QCBKSWiifmEtQB2jlqHYu

haddock-interfaces:
    /usr/share/doc/haskell-network-protocol-xmpp/html/network-protocol-xmpp.haddock

haddock-html:         /usr/share/doc/haskell-network-protocol-xmpp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
